#!/bin/sh
# TODO:
# - Extraer fichero y automatizar el proceso de instalación descrito en:
#   https://fran.cr/instalar-firma-digital-costa-rica-gnu-linux-ubuntu-debian/

# main
set_lang
set_version

if [ -e "/bin/zenity" ] ; then
    MENU="zenity"
    # Welcome
    zenity --title "$TITLE" --text "$PROMPT_WELCOME" --info

    # Select file to be downloaded if os can't be determined
    [ -z "$FILE" ] && FILE="$(zenity --title "$TITLE" --text "$PROMPT_FILE" --list \
        --column "$FILENAME" --column "$FILEDESC" \
        "ClientesMac_rev34.zip" "macOSX 10.14 o superior" \
        "ClientesLinux_DEB64_Rev25.zip" "Ubuntu 18.04 LTS o superior, Debian 10" \
        "ClientesLinux_CentOS7_Rev6.zip" "CentOS 7" \
        "ClientesLinux_RPM64_Rev24.zip" "Fedora 34 o superior, CentOS Stream 9" \
        --print-column=1)"

    install_deps "$MENU" | zenity --title "$TITLE" --text "$PROMPT_DEPS" --progress --pulsate --auto-close

    # Ask for serial number
    SERIAL="$(zenity --title "$TITLE" --text "$PROMPT_SERIAL" --entry)"
    [ -z "$SERIAL" ] && zenity --title "$TITLE" --text "$PROMPT_ERR_SERIAL" --error && exit 1

    # Generate tempkey & Define DOWNLOAD_URL
    TEMPKEY="$(download_iso "$FILE" "$SERIAL" | sed '/tempkey/!d;s/.*tempkey=//g;s/".*$//g')"
    [ -z "$TEMPKEY" ] && zenity --title "$TITLE" --text "$PROMPT_ERR_DOWNLOAD" --error && exit 1
    DOWNLOAD_URL="https://soportefirmadigital.com/sfdj/getiso.aspx?tempkey=$TEMPKEY"

    # Define where to save file
    if [ -d "/tmp" ] ; then
        SAVE_DIR="/tmp/soportefirmadigital"
        mkdir -p "$SAVE_DIR"
    else
        zenity --title "$TITLE" --text "$PROMPT_DIR_FILE" --info
        SAVE_DIR="$(zenity --file-selection --directory)"
    fi
    [ -z "$SAVE_DIR" ] && zenity --title "$TITLE" --text "$PROMPT_ERR_DIR_FILE" --error && exit 1
    SAVE_FILE="$SAVE_DIR/$FILE"

    # Download file & show progress
    SIZE="$(curl -sI "$DOWNLOAD_URL" | sed '/[Cc]ontent-[Ll]ength/!d;s/^.*: //g' | awk '{$1/=1024;printf "%d",$1}')"
    (curl "$DOWNLOAD_URL" -o "$SAVE_FILE") &
    while true ; do
        sleep 0.5
        DOWN="$(du "$SAVE_FILE" 2>/dev/null | awk '{print $1}')" ; [ -z "$DOWN" ] && DOWN=0
        r=$(((DOWN*10000)/SIZE))
        printf '%d\n' ${r%??}
    done | zenity --title "$TITLE" --text "$PROMPT_DOWNLOAD" --progress --auto-close

    while true ; do
        ACTIVE="$(ps aux | grep 'curl.*soportefirmadigital' | sed '/grep/d')"
        [ -z "$ACTIVE" ] && break
        sleep 0.5
    done | zenity --title "$TITLE" --text "$PROMPT_DOWNLOAD" --progress --pulsate --auto-close

    ACTIVE="$(ps aux | grep 'curl.*soportefirmadigital' | sed '/grep/d')"
    [ -n "$ACTIVE" ] && zenity --title "$TITLE" --text "$PROMPT_ERR_DOWNLOAD" --error && exit 1

    if [ "$FILE" = "ClientesMac_rev34.zip" ] ; then
        echo
    elif [ "$FILE" = "ClientesLinux_DEB64_Rev25.zip" ] ; then
        config_deb_install_certs "$SAVE_FILE"
    elif [ "$FILE" = "ClientesLinux_CentOS7_Rev6" ] ; then
        echo
    elif [ "$FILE" = "ClientesLinux_RPM64_Rev24" ] ; then
        echo
    fi

else
    echo
    # Welcome
    #term_prompt "$TITLE" "$PROMPT_WELCOME" info && read -r NULL

    # Select file to be downloaded
    #LIST="$(printf '\033[4m1\033[0m - ClientesMac_rev34.zip           | macOSX 10.14 o superior
# \03[4m2\033[0m - ClientesLinux_DEB64_Rev25.zip   | Ubuntu 18.04 LTS o superior, Debian 10
# \03[4m3\033[0m - ClientesLinux_CentOS7_Rev6.zip  | CentOS 7
# \03[4m4\033[0m - ClientesLinux_RPM64_Rev24.zip   | Fedora 34 o superior, CentOS Stream 9')"
    #term_prompt "$TITLE" "$PROMPT_FILE" list "$LIST" && read -r FILE
    #[ "$FILE" = "1" ] && FILE="ClientesMac_rev34.zip"
    #[ "$FILE" = "2" ] && FILE="ClientesLinux_DEB64_Rev25.zip"
    #[ "$FILE" = "3" ] && FILE="ClientesLinux_CentOS7_Rev6.zip"
    #[ "$FILE" = "4" ] && FILE="ClientesLinux_RPM64_Rev24.zip"

    # Ask for serial number
    #term_prompt "$TITLE" "$PROMPT_SERIAL" entry && read -r SERIAL
    #[ -z "$SERIAL" ] && term_prompt "$TITLE" "$PROMPT_ERR_SERIAL" error && exit 1

    # Generate tempkey & Define DOWNLOAD_URL
    #TEMPKEY="$(download_iso "$FILE" "$SERIAL" | sed '/tempkey/!d;s/.*tempkey=//g;s/".*$//g')"
    #[ -z "$TEMPKEY" ] && term_prompt "$TITLE" "$PROMPT_ERR_DOWNLOAD" error && exit 1
    #DOWNLOAD_URL="https://soportefirmadigital.com/sfdj/getiso.aspx?tempkey=$TEMPKEY"

    # Define where to save file
    #mkdir -p "$HOME/Library/Caches/TemporaryItems/instalador-firma-digital"
    #SAVE_FILE="$HOME/Library/Caches/TemporaryItems/instalador-firma-digital/$FILE"

    # Download file & show progress
    #term_prompt "$TITLE" "$PROMPT_DOWNLOAD" info && echo
    #curl "$DOWNLOAD_URL" -o "$SAVE_FILE" --progress-bar
fi
